
if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes' ) )
	drop table A_CallRoutes
GO

Create Table dbo.A_CallRoutes
(
   Id uniqueidentifier,
   Name nvarchar ( 200 ),
   Description nvarchar ( 1000 ),
   Command nvarchar ( 1000 ),
   IsExternal bit,
   Enabled bit
)
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_Lines' ) )
	drop table A_CallRoutes_Lines
GO

Create Table A_CallRoutes_Lines
(
   IdRoute uniqueidentifier,
   IdLine uniqueidentifier,
   Pos int
)
GO
   

if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_GetAll' ) )
	drop procedure A_CallRoutes_GetAll
GO

Create procedure dbo.A_CallRoutes_GetAll
as
begin
	Select Id, Name, Description, Command, IsExternal, Enabled
	From A_CallRoutes
	Order By Name
end
GO

if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_Save' ) )
	drop procedure A_CallRoutes_Save
GO

Create procedure dbo.A_CallRoutes_Save
	@id uniqueidentifier,
	@name nvarchar ( 200 ),
   	@description nvarchar ( 1000 ),
   	@command nvarchar ( 1000 ),
	@isexternal bit,
	@enabled bit
as
begin
	Update A_CallRoutes
	Set 	Name = @name,
		Description = @description,
		Command = @command,
		IsExternal = @isexternal,
		Enabled = @enabled
	Where Id = @id

	if ( @@rowcount = 0 )
		Insert into A_CallRoutes ( Id, Name, Description, Command, IsExternal, Enabled )
		Values ( @id, @name, @description, @command, @isexternal, @enabled )
end
GO



if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_ChangeEnabled' ) )
	drop procedure A_CallRoutes_ChangeEnabled
GO

Create procedure dbo.A_CallRoutes_ChangeEnabled
	@id uniqueidentifier,	
	@enabled bit
as
begin
	Update A_CallRoutes
	Set Enabled = @enabled
	Where Id = @id	
end
GO



if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_Delete' ) )
	drop procedure A_CallRoutes_Delete
GO

Create procedure dbo.A_CallRoutes_Delete
	@id uniqueidentifier
as
begin
	Delete 
	From A_CallRoutes
	Where Id = @id

	Delete
	From A_CallRoutes_Lines
	Where IdRoute = @id
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_LoadLines' ) )
	drop procedure A_CallRoutes_LoadLines
GO

Create procedure dbo.A_CallRoutes_LoadLines	
as
begin
	Select rl.IdRoute, rl.IdLine, rl.Pos, cast ( l.SystemNum as nvarchar ( 10 ) ) as SystemNum
	From A_CallRoutes r
		Inner join A_CallRoutes_Lines rl on r.Id = rl.IdRoute
		Inner join A_View_ServerLinesAll l on rl.IdLine = l.Id
	Order By rl.IdRoute, rl.Pos
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_LinesClear' ) )
	drop procedure A_CallRoutes_LinesClear
GO

Create procedure dbo.A_CallRoutes_LinesClear
	@idroute uniqueidentifier
as
begin
	Delete 
	From A_CallRoutes_Lines
	Where IdRoute = @idroute
end
GO


if exists ( Select * FROM sysobjects where id = object_id ( 'dbo.A_CallRoutes_LineSave' ) )
	drop procedure A_CallRoutes_LineSave
GO

Create procedure dbo.A_CallRoutes_LineSave
	@idroute uniqueidentifier,
	@idline uniqueidentifier,
	@pos int
as
begin
	Insert into A_CallRoutes_Lines ( IdRoute, IdLine, Pos )
	Values ( @idroute, @idline, @pos )
end
GO