if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Stat_Office_GetJournal' ) )
	Drop procedure dbo.A_Stat_Office_GetJournal
GO


Create procedure [dbo].[A_Stat_Office_GetJournal]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = NULL, --Task defined
	@fromcc bit = NULL,
	@operatorid uniqueidentifier = NULL, --Operator defined
	@innerprefix nvarchar(100) = NULL, --Internal Number defined
	@outnumber nvarchar(100) = NULL,  --Out Number defined
	@conntype int = -1
as
begin	
	Select top 0 *, 0 as IsConf, GetDate() as CTS into #t from A_Stat_Connections_1x1
	Insert into #t Exec A_Stat_Service_FillTempByFilter
		@iduser,
		@dstart,
		@dstop,
		@tstart,
		@tstop,
		@lentime,
		@taskid,
		@fromcc,
		@operatorid,
		@innerprefix,
		@outnumber,
		@conntype,
		1 -- show conference

	Select top 1000 t.*, TimeStop - TimeAnswer as Length, TimeAnswer - TimeStart as AnswerLength
	From #t t
	Order By TimeStart Desc
end
GO


if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Stat_Service_FillTempByFilter' ) )
	Drop procedure dbo.A_Stat_Service_FillTempByFilter
GO

Create PROCEDURE [dbo].[A_Stat_Service_FillTempByFilter]
	@iduser uniqueidentifier,
	@dstart datetime,
	@dstop datetime,
	@tstart datetime,
	@tstop datetime,
	@lentime datetime,
	@taskid uniqueidentifier = NULL, --Task defined
	@fromcc bit = NULL,
	@operatorid uniqueidentifier = NULL, --Operator defined
	@innerprefix nvarchar(100) = NULL, --Internal Number defined
	@outnumber nvarchar(100) = NULL,  --Out Number defined
	@conntype int = -1,
	@showconf bit = 0
AS
begin

	--Prepare @A_Stat_Connections_1x1_tmp
	Declare @A_Stat_Connections_1x1_tmp1 table( Id uniqueidentifier PRIMARY KEY) 
	Declare @A_Stat_Connections_1x1_tmp table( Id uniqueidentifier PRIMARY KEY, AUSerId uniqueidentifier, BUSerId uniqueidentifier, ALineId uniqueidentifier, BLineId uniqueidentifier) 
	declare @tstartfloat float  declare @tstopfloat float 
	set @tstartfloat = Convert ( float, @tstart )  
	set @tstopfloat  = Convert ( float, @tstop )  
	set @tstartfloat = @tstartfloat - FLOOR ( @tstartfloat )  
	set @tstopfloat = @tstopfloat - FLOOR ( @tstopfloat )  

	declare @lt float
	set @lt = Convert ( float, @lentime ) - Floor ( Convert ( float, @lentime ) )


	--Date & Time Intervals
	Insert into @A_Stat_Connections_1x1_tmp 
	select Id, AUSerId , BUSerId , ALineId , BLineId 
	from A_Stat_Connections_1x1 sc --With ( TabLock )
	where 
		 ( TimeStart >= @dstart ) and ( TimeStart < @dstop ) 
		and ( Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) >= @tstartfloat )  
		and ( Convert ( float, TimeStart ) - FLOOR ( Convert ( float, TimeStart ) ) <= @tstopfloat ) 
		and ( CONVERT ( float, TimeStop ) - Convert ( float, TimeAnswer ) >= @lt )
		and (( FromCC is null ) or ( FromCC <= @fromcc ))
		and (@conntype = -1 or (@conntype = 1 and ConnectionType in (4,5)) or (@conntype = 2 and ConnectionType in (1,6,7)) or (@conntype = 3 and ConnectionType in (2,3,8)))
	
		--and not exists(select id from  @A_Stat_Connections_1x1_tmp where id=sc.ID)


	--Permissions
	--Users
	declare @upermitted table ( Id uniqueidentifier Primary Key )
	Insert into @upermitted
		Select UserB
		From A_UserControls auc
		Where UserA = @iduser

	if not exists (select UserB from  A_UserControls where UserA = @iduser and UserB = @iduser)
		Insert into @upermitted (Id) Values (@iduser)

	Declare @commpermitted table ( Id uniqueidentifier PRIMARY KEY)  	 -- Id Connection
	Insert into @commpermitted
		Select  sc.ID --auc.UserB   	
		From @upermitted up
			inner join @A_Stat_Connections_1x1_tmp sc on up.Id = sc.AUserId
	
	Insert into @commpermitted
		Select  sc.ID --auc.UserB   	
		From @upermitted up
			inner join @A_Stat_Connections_1x1_tmp sc on up.Id=sc.BUserId
		Where not exists(select id from @commpermitted where Id=sc.ID)


	--Lines
	print '------Lines'
	declare @lpermitted table ( Id uniqueidentifier Primary Key )
	Insert into @lpermitted
    	 Select IdLine
    	 From A_UserControlLines
    	 Where UserA = @iduser
          and IdLine != '11111111-1111-1111-1111-111111111111'       

	declare @canlistenext int       
	Select @canlistenext = Count ( * ) 
	From A_UserControlLines 
	Where UserA = @iduser and IdLine = '11111111-1111-1111-1111-111111111111'

	if ( @canlistenext > 0 )
    		Insert into @lpermitted
	          Select Id 
        	  From A_ServerExtLines sel
	          Where not exists(select id from @lpermitted where Id = sel.ID)
     
	Insert into @commpermitted
    	 Select sc.ID            
    	 From @lpermitted l
          inner join @A_Stat_Connections_1x1_tmp sc on sc.ALineId=l.Id
    	 Where not exists(select id from @commpermitted where Id = sc.ID)

	Insert into @commpermitted            
    	 Select sc.ID            
    	 From @lpermitted l
          inner join @A_Stat_Connections_1x1_tmp sc on  sc.BLineId=l.Id
    	 Where not exists(select id from @commpermitted where Id = sc.ID)

	print '------Lines'

	delete @A_Stat_Connections_1x1_tmp 
	where id not in (select Id from @commpermitted )

--Numbers 
	--Inner
	if @innerprefix is not null 
	begin
		declare @t table ( nid uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, reactid uniqueidentifier )
		declare @temp table ( id uniqueidentifier, prefix nvarchar ( 50 ) collate database_default, addrtype int, oldrid uniqueidentifier, newrid uniqueidentifier )

		Insert Into @t
			Select np.Id, np.Prefix, rr.InnerAddressType, rr.ReactId
			From A_NumberPlan np
				Inner join A_NumberPlanAction na on na.NumId = np.Id
				Inner join A_Rules r on na.ExtraId = r.Id
				Inner join A_RuleRecords rr on rr.RuleId = r.Id

		declare @cnt int
		set @cnt = 0

		while ( @@rowcount > 0 ) and ( @cnt < 10 )
		begin
			Set @cnt = @cnt + 1

			/*    @cnt - */
			Insert Into @temp
				Select t.nid, t.prefix, t.addrtype, t.reactid, t1.reactid
				From @t t
					Inner join @t t1 on t.Reactid = t1.nId
				Where t.ReactId != t.Nid

			/*    */
			Delete From @t
				From @temp
			Where nid = id and reactid = oldrid

			/* */
			Insert Into @t ( nid, prefix, addrtype, reactid )
				Select id, prefix, addrtype, newrid 
				From @temp

			/* */
			Delete From @temp	
		end --\MakePrefixTableAnyWay condition

		

		--Users
		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.AUserID=t.reactid
		where addrtype = 0 and prefix like @innerprefix

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.BUserID=t.reactid
		where addrtype = 0 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		--Lines
		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.AUserID=t.reactid
		where addrtype = 1 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
			inner join @t t on sc.BUserID=t.reactid
		where addrtype = 1 and prefix like @innerprefix
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)
		
		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1
		
	end --\NUmbers

	--Outer NUMBVERS
	if @OutNumber is not null begin

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from A_Stat_Connections_1x1 sc --With ( TabLock )
		where  AOutNumber like '%'+@OutNumber+'%'

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from A_Stat_Connections_1x1 sc --With ( TabLock )
		where  BOutNumber like '%'+@OutNumber+'%'
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1

	end
	--\Outer NUMBVERS

	--operatorid
	if @operatorid is not null begin

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id
		from @A_Stat_Connections_1x1_tmp sc
		where  AUserId=@operatorid

		Insert into @A_Stat_Connections_1x1_tmp1 
		select Id 
		from @A_Stat_Connections_1x1_tmp sc
		where  BUserId=@operatorid
			and not exists(select id from  @A_Stat_Connections_1x1_tmp1 where id=sc.ID)

		delete @A_Stat_Connections_1x1_tmp 
			where id not in (select Id from @A_Stat_Connections_1x1_tmp1 )
		delete @A_Stat_Connections_1x1_tmp1
	end


	


	-- 

	/*Declare @upermitted table ( Id uniqueidentifier )
	Insert into @upermitted 
		Select Id From A_USers
	
	Declare @dstart datetime
	Declare @dstop datetime
	Set @dstart = DateAdd ( d, -5, GetDate() )
	Set @dstop = GetDate()
*/
    if ( @showconf = 0 )
    begin

	Select sc.*
	FROM A_Stat_Connections_1x1 sc --With ( TabLock )--,@ulpermitted ul,@tasks t
		Inner join @A_Stat_Connections_1x1_tmp sct on sc.Id=sct.Id
		--Inner Join @commpermitted cp on sc.ID=cp.ID
    end

    else

    begin

	--   	
	Declare @A_Stat_Conference_tmp1 table ( Id uniqueidentifier PRIMARY KEY, RecordAccess int, Director uniqueidentifier )

	Insert into @A_Stat_Conference_tmp1
		Select Id, RecordAccess, Director 
		FROM A_Stat_Conference sc
		Where (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart < @dstop ) and ( TimeStop >= @dstop ))
			or (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart >= @dstart ) and ( TimeStop <= @dstop ))


	--   
	Declare @A_Stat_Conference_tmp2 table ( Id uniqueidentifier PRIMARY KEY )

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join @upermitted up on sc.Director = up.Id
		Where sc.RecordAccess = 1 --  

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
			Inner join A_Stat_Conference_Competitors scc on sc.Id = scc.IdConf
			Inner join @upermitted up on scc.IdUser = up.Id
		Where sc.RecordAccess = 2 -- 
		Group By sc.Id

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join A_Stat_Conference_RecordAccessUsers scr on sc.Id = scr.IdConf
			Inner join @upermitted up on scr.IdUser = up.Id
		Where sc.RecordAccess = 3 --  
		Group By sc.Id

		

	Declare @idempty uniqueidentifier
	Set @idempty = '00000000-0000-0000-0000-000000000000'
	
	Declare @idconfuser uniqueidentifier
	Set @idconfuser = 'CF000000-0000-0000-0000-000000000000'


	Select * From
	(
		Select sc.*, 0 as IsConf, sc.TimeStart as CTS
		FROM A_Stat_Connections_1x1 sc --With ( TabLock )--,@ulpermitted ul,@tasks t
			Inner join @A_Stat_Connections_1x1_tmp sct on sc.Id=sct.Id
			--Inner Join @commpermitted cp on sc.ID=cp.ID

		Union All


		Select IdConn, IdChain, @idempty as IdPrev, @idempty as IdNext, 
			scc.TimeStart, scc.TimeStart as TimeAnswer, scc.TimeStop, 
			ReasonStart, ReasonStop, 0 as StopSide, 
			IdLine, IdConf, OutNumber, '', LineNum, cast ( Room as nvarchar ( 10 ) ), 
			IdUser, @idconfuser, '', '', IsRecorded, case when sc.Type = 1 then 11/**/ else 10/**/ end, 
			StrName, case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end, 
			0, 1, IdRecDir, 1 as IsConf, sc.TimeStart as CTS
		FROM A_Stat_Conference_Competitors scc
			Inner join A_Stat_Conference sc on sc.Id = scc.IdConf
			Inner join @A_Stat_Conference_tmp2 sct on sc.Id = sct.Id --  
			--Inner join @upermitted up on up.Id = scc.IdUser --             
		Where (( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart < @dstop ) and ( scc.TimeStop >= @dstop ))
			or (( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart >= @dstart ) and ( scc.TimeStop <= @dstop ))
	)a
    end

end
GO



if exists ( Select * From sysobjects where id = object_id ( 'dbo.A_Stat_MyCalls_Get' ) )
	Drop procedure dbo.A_Stat_MyCalls_Get
GO


Create procedure [dbo].[A_Stat_MyCalls_Get]
	@media 		int, --1 - , 2 - , 3 - , 0 - 
	@type 		int, --1 - , 2 - , 3 - , 0 - , 10 - , 11 - 
	@dstart 	datetime,
	@dstop 		datetime,
	@number 	nvarchar ( 50 ),
	@showivr 	bit,
	@userid 	uniqueidentifier
as
begin

/*
	declare @media 	int --1 - , 2 - , 3 - , 0 - 
	declare @type 	int --1 - , 2 - , 3 - , 0 - 
	declare @dstart datetime
	declare @dstop 	datetime
	declare @number nvarchar ( 50 )
	declare @userid uniqueidentifier

	set dateformat dmy
	set @media = 0
	set @type = 0
	set @dstart = '16.12.2006'
	set @dstop = '16.12.2006'
	set @number = ''
	select @userid = id from A_users where login like 'Peter'

*/
	Declare @ids table ( id uniqueidentifier )	

	if ( @number = '' )
		Insert into @ids
			Select Id
			From A_Stat_Connections_1x1 sc --with ( TabLock )
			Where TimeStart > @dstart 
				and TimeStart < @dstop
				and (( AUserId = @userid and (@type = 2 or @type = 0) ) or ( BUserId = @userid and ( @type = 1  or @type = 0 ) ))
				and ( @showivr = 1 or (( AUserId != 'AB000000-0000-0000-0000-000000000000' ) and ( BUserId != 'AB000000-0000-0000-0000-000000000000' )))
	else
		Insert into @ids
			Select Id
			From A_Stat_Connections_1x1 sc --with ( TabLock )
			Where TimeStart > @dstart 
				and TimeStart < @dstop
				and (( AUserId = @userid and (@type = 2 or @type = 0) and BOutNumber like @number ) or ( BUserId = @userid and ( @type = 1  or @type = 0 ) and AOutNumber like @number ))	
				and ( @showivr = 1 or (( AUserId != 'AB000000-0000-0000-0000-000000000000' ) and ( BUserId != 'AB000000-0000-0000-0000-000000000000' )))
		
	Declare @output table ( Id uniqueidentifier, IdChain uniqueidentifier, Media int, Type int, TimeStart DateTime, Length DateTime, Number nvarchar ( 50 ) collate database_default, AbonentName nvarchar ( 100 ) collate database_default, 
				IsRecorded int, IdRecDir int, ALineNum nvarchar ( 5 ) collate database_default, BLineNum nvarchar ( 5 )  collate database_default, --ARecFile nvarchar ( 100 ), BRecFile nvarchar ( 100 ), 
				AUserId uniqueidentifier, BUserId uniqueidentifier, 
				ALineId uniqueidentifier, BLineId uniqueidentifier, 
				AOutNumber nvarchar ( 50 ) collate database_default, BOutNumber nvarchar ( 50 ) collate database_default, 
				AStr nvarchar ( 100 ) collate database_default, BStr nvarchar ( 100 ) collate database_default, IsConf int, CTS DateTime )
	-------------------------------------
	--  -----------------------
	-------------------------------------

	Insert into @output
		Select sc.Id, sc.IdChain, null, 0, sc.TimeStart, sc.TimeStop - sc.TimeAnswer as Length, '', '',
			IsRecorded, IdRecDir, ALineNum, BLineNum, --ARecFile, BRecFile, 
			AUserId, BUserId, ALineId, BLineId, AOutNumber, BOutNumber, AStr, BStr,
			0 as IsConf, sc.TimeStart as CTS
		From A_Stat_Connections_1x1 sc --with ( TabLock )
			inner join @ids ids on sc.Id = ids.id

	-------------------------------------
	--  ----------------------
	-------------------------------------
    if (( @type = 0 ) or ( @type = 10 ) or ( @type = 11 ))
    begin
	

	--   	
	Declare @A_Stat_Conference_Ctmp1 table ( IdConn uniqueidentifier PRIMARY KEY )
	Declare @A_Stat_Conference_tmp1 table ( Id uniqueidentifier PRIMARY KEY, RecordAccess int, Director uniqueidentifier )

	Insert into @A_Stat_Conference_Ctmp1
		Select IdConn
		FROM A_Stat_Conference_Competitors scc
		Where (( TimeStart >= @dstart ) and ( TimeStart < @dstop ))
			And IdUser = @userid

	Insert into @A_Stat_Conference_tmp1
		Select Id, RecordAccess, Director 
		FROM A_Stat_Conference sc
		Where (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart < @dstop ) and ( TimeStop >= @dstop ))
			or (( TimeStart <= @dstart ) and ( TimeStop > @dstart ))
			or (( TimeStart >= @dstart ) and ( TimeStop <= @dstop ))

	--   
	Declare @A_Stat_Conference_tmp2 table ( Id uniqueidentifier PRIMARY KEY )

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
		Where sc.RecordAccess = 1 --  
			And sc.Director = @userid

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc			
			Inner join A_Stat_Conference_Competitors scc on sc.Id = scc.IdConf
		Where sc.RecordAccess = 2 -- 
			And scc.IdUser = @userid
		Group By sc.Id

	Insert into @A_Stat_Conference_tmp2
		Select sc.Id From @A_Stat_Conference_tmp1 sc
			Inner join A_Stat_Conference_RecordAccessUsers scr on sc.Id = scr.IdConf
		Where sc.RecordAccess = 3 --  
			And scr.IdUser = @userid
		Group By sc.Id

		

	Declare @idconfuser uniqueidentifier
	Set @idconfuser = 'CF000000-0000-0000-0000-000000000000'

	Insert into @output
		Select IdConn, IdChain, 
			case when sc.Type = 1 then 11/**/ else 10/**/ end, 
			case when sc.Type = 1 then 11/**/ else 10/**/ end,
			scc.TimeStart, scc.TimeStop - scc.TimeStart as Length, 
			'', case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end,
			case when ( sct.Id is NULL ) then 0 else sc.IsRecorded end,  
			sc.IdRecDir, LineNum, sc.Room, 
			scc.IdUser, @idconfuser,
			scc.IdLine, IdConf,
			'', '', StrName, case when Name != '' then Name else '#' + cast ( Room as nvarchar ( 10 ) ) end,
			1 as IsConf, sc.TimeStart as CTS
		FROM A_Stat_Conference_Competitors scc
			Inner join A_Stat_Conference sc on sc.Id = scc.IdConf
			Left join @A_Stat_Conference_tmp2 sct on sc.Id = sct.Id --    
		Where ((( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart < @dstop ) and ( scc.TimeStop >= @dstop ))
			or (( scc.TimeStart <= @dstart ) and ( scc.TimeStop > @dstart ))
			or (( scc.TimeStart >= @dstart ) and ( scc.TimeStop <= @dstop )))
			And scc.IdUser = @userid
			And ((( sc.Type = 1 ) and ( @type = 11 )) or (( sc.Type = 0 ) and ( @type = 10 )) or ( @type = 0 ))
    end

	-----------------------------------
  	--  -----------------
	-----------------------------------

	Update o
	Set o.Type =  1,
		o.Number = AOutNumber
	From @output o
	Where o.BUserId = @userid
		And Type = 0

	Update o
	Set o.Type =  2,
		o.Number = BOutNumber
	From @output o
	Where o.AUserId = @userid
		And Type = 0

	Update o
	Set o.Media = 1
	From @output o, A_ServerExtLines el
	Where o.ALineId = el.Id or o.BLineId = el.Id

	Update o
	Set o.Media = 2
	From @output o
	Where o.Media is null
	
	Update o
	Set o.AbonentName = u.Name
	From @output o, A_Users u
	Where ( o.AUserId = @userid and o.BUserId = u.Id ) or ( o.BUserId = @userid and o.AUserId = u.Id )

	Update o
	Set o.AbonentName = c.Name
	From @output o, A_Clients c, A_ClientContacts cc
	Where o.Number = cc.Content and cc.IdClient = c.Id

	if ( @showivr = 1 )
		Update o
		Set o.AbonentName = 'IVR'
		From @output o
		Where o.AUserId = 'AB000000-0000-0000-0000-000000000000' or o.BUserId = 'AB000000-0000-0000-0000-000000000000'

	Update o
	Set o.AbonentName = case When o.Type = 1 Then o.AStr else o.BStr end
	From @output o
	Where o.AbonentName = ''-- and o.Number = ''

	Update o
	Set o.AbonentName = ''
	From @output o
	Where o.AbonentName = o.Number


	Select Id, IdChain, Media, Type, TimeStart, Length, ALineNum, BLineNum, Number, AbonentName, IsRecorded, IdRecDir, IsConf, CTS--, ARecFile, BRecFile
	From @output
	Where ( Media = @media ) or ( @media = 0 ) or ( Type >= 10 )
	Order By TimeStart Desc
end

GO